rm(list = ls())
library(BMA)

data <- read.delim("c:/CEP_EER_XLS.txt", header = TRUE)

Ycredit <- as.matrix(data["CREDIT_bankliquidrestoass"])
Yfx_res <- as.matrix(data["fx_res_index"])
Ygdp <- as.matrix(data["realgdp"])
Yimf <- as.matrix(data["imf_all"])
Yimf_sba <- as.matrix(data["imf_sba"])
Yimf_prgfesf <- as.matrix(data["imf_prgfesf"])

X.lab <- c(
"CA_ca_pct_gdp",
"CA_caavlast5yrs_pct_gdp",
"CA_currenttransfersreceiptsusd",
"CA_currenttransfersusd",
"CA_merchandisetrade_pct_gdp",
"CA_mgoodsgdp",
"CA_mgservicegdp",
"CA_remittancesreceived_pct_gdp",
"CA_savingsdomestic_pct_gdp",
"CA_tradebalance_pct_gdp",
"CA_xgoodsgdp", 
"CA_xgservicegdp", 
"CREDIT_credit_domestic_pct_gdp",
"CREDIT_credit_domestic_pctgdp_5yr_rise",
"CREDIT_creditdepthofinfo",
"CREDIT_domesticcreditbybanks_pct_gdp",
"CREDIT_domesticcreditlcu",
"CREDIT_domesticcredittotal_pct_gdp",
"DEM_govexp_pct_gdp",
"DEM_incomenetbopusd",
"DEM_investment_pct_gdp",
"DEM_publicdebtgdp",
"FX_reer5yr",
"FX_reerdev10yravg",
"FX_reserves_perc_gdp_constr",
"FX_reserveschangesusd",##gdp if dem in
"FX_reservesusd",##gdp if dem in
"INFL_cpi2007",
"INFL_cpiavlast5years",
"INFL_gdpdeflator",
"INFL_gdpdeflator_pct_annual",
"INST_businessdisclosure",
"INST_legalrightsindex",
"KFLOW_fdicurrentusd",
"KFLOW_fdiinflows_pct_gdp",
"KFLOW_fdiinflowsusd",
"KFLOW_financiallyclosed",
"KFLOW_foreignassetsnetlcucurrent",
"KFLOW_portfolioinvequityusd",
"MONEY_m2_pct_gdp",
"MONEY_m2growth_pct_",
"MONEY_realintrate",
#
# only geo regions
#
"REGION_eapacific",
"REGION_euroarea",
"REGION_latamcarribean",
"REGION_mena",
"REGION_northamerica",
"REGION_southasia",
"REGION_subsaharan",
"REGION_lowincome",
#Interactions
#"xCREDIT",   # ==> equals domesticcreditbybanks_pct_gdp * credit_domestic_pctgdp_5yr_rise
# Upper Income dummy interacted with all vars below)
"xRUCA_ca_pct_gdp",
"xRUCA_ca2007_pct_gdp",
"xRUCA_caavlast5yrs_pct_gdp",
"xRUCA_currenttransfersreceiptsusd",
"xRUCA_currenttransfersusd",
"xRUCA_merchandisetrade_pct_gdp",
"xRUCA_mgoodsgdp",
"xRUCA_mgservicegdp",
"xRUCA_remittancesreceived_pct_gdp",
"xRUCA_savingsdomestic_pct_gdp",
"xRUCA_tradebalance_pct_gdp",
"xRUCA_xgoodsgdp",
"xRUCA_xgservicegdp",
"xRUCREDIT_credit_domestic_pct_gdp",
"xRUCREDIT_credit_domestic_pctgdp_5yr_rise",
"xRUCREDIT_creditdepthofinfo",
"xRUCREDIT_domesticcreditbybanks_pct_gdp",
"xRUCREDIT_domesticcreditlcu",
"xRUCREDIT_domesticcredittotal_pct_gdp",
"xRUDEM_consumption_pct_gdp",
"xRUDEM_govexp_pct_gdp",
"xRUDEM_incomenetbopusd",
"xRUDEM_investment_pct_gdp",
"xRUDEM_publicdebtgdp",
"xRUDEM_savings_pct_gni",
"xRUFX_reer5yr",
"xRUFX_reerdev10yravg",
"xRUFX_reserves_perc_gdp_constr",
"xRUFX_reserveschangesusd",
"xRUFX_reservesusd",
"xRUINFL_cpi2007",
"xRUINFL_cpiavlast5years",
"xRUINFL_gdpdeflator",
"xRUINFL_gdpdeflator_pct_annual",
"xRUINST_businessdisclosure",
"xRUINST_legalrightsindex",
"xRUKFLOW_fdicurrentusd",
"xRUKFLOW_fdiinflows_pct_gdp",
"xRUKFLOW_fdiinflowsusd",
"xRUKFLOW_foreignassetsnetlcucurrent",
"xRUKFLOW_portfolioinvequityusd",
"xRUMONEY_m2_pct_gdp",
"xRUMONEY_m2growth_pct_",
"xRUMONEY_m2lcu",
"xRUMONEY_m2lcu_100mil",
"xRUMONEY_realintrate",
"REGION_upperincome"
)
X.lab_credit <- c(
"xRUCREDIT_bankliquidrestoass",
"CREDIT_bankliquidrestoass"
)

X.lab_gdp <- c(
"GDP_gdpgrowth2007",
"GDP_gdpgrowthlast5yrs",
"GDP_gdppercapitagrowth",
"GDP_gdppercapitapppcurrentusd",
"GDP_gdppppcurrentusd",
"xRUGDP_gdpgrowth2007",
"xRUGDP_gdpgrowthlast5yrs",
"xRUGDP_gdppercapitagrowth",
"xRUGDP_gdppercapitapppcurrentusd",
"xRUGDP_gdppppcurrentusd"
)

X_base <- data[X.lab] #basic dataset with min set of regressors
X_credit <- data[X.lab_credit] # add credit regressors for all non-credit-dependent-var runs
X_gdp <- data[X.lab_gdp] # add gdp vars for all non-gdp-dependent-var runs

#create datasets

#ALL
X <- as.matrix(cbind(X_base, X_credit, X_gdp))

#GDP
Xgdp <- cbind(X_base, X_credit)

#credit
Xcredit <- cbind(X_base, X_gdp)

#IBMA
credit <-iBMA.bicreg(Xcredit, Ycredit, thresProbne0 = .005, maxNvar = 30, nIter = 100, nbest = 5, verbose = FALSE, sorted = FALSE)
fx_res <-iBMA.bicreg(X, Yfx_res, thresProbne0 = .005, maxNvar = 30, nIter = 100, nbest = 5, verbose = FALSE, sorted = FALSE)
gdp <-iBMA.bicreg(Xgdp, Ygdp, thresProbne0 = .005, maxNvar = 30, nIter = 100, nbest = 5, verbose = TRUE, sorted = FALSE)

summary(credit)
summary(fx_res)
summary(gdp)



