rm(list = ls())
library(BMA)

data <- read.delim("c:/CEP_EER_XLS.txt", header = TRUE)

Ycredit <- as.matrix(data["CREDIT_bankliquidrestoass"])
Yfx_res <- as.matrix(data["fx_res_index"])
Ygdp <- as.matrix(data["realgdp"])
Yimf <- as.matrix(data["imf_all"])
Yimf_sba <- as.matrix(data["imf_sba"])
Yimf_prgfesf <- as.matrix(data["imf_prgfesf"])

X.lab <- c(
"CA_ca_pct_gdp",
"CA_caavlast5yrs_pct_gdp",
"CA_currenttransfersreceiptsusd",
"CA_currenttransfersusd",
"CA_merchandisetrade_pct_gdp",
"CA_mgoodsgdp",
"CA_mgservicegdp",
"CA_remittancesreceived_pct_gdp",
"CA_savingsdomestic_pct_gdp",
"CA_tradebalance_pct_gdp",
"CA_xgoodsgdp", 
"CA_xgservicegdp", 
"CREDIT_credit_domestic_pct_gdp",
"CREDIT_credit_domestic_pctgdp_5yr_rise",
"CREDIT_creditdepthofinfo",
"CREDIT_domesticcreditbybanks_pct_gdp",
"CREDIT_domesticcreditlcu",
"CREDIT_domesticcredittotal_pct_gdp",
"DEM_govexp_pct_gdp",
"DEM_incomenetbopusd",
"DEM_investment_pct_gdp",
"DEM_publicdebtgdp",
"FX_reer5yr",
"FX_reerdev10yravg",
"FX_reserves_perc_gdp_constr",
"FX_reserveschangesusd",##gdp if dem in
"FX_reservesusd",##gdp if dem in
"INFL_cpi2007",
"INFL_cpiavlast5years",
"INFL_gdpdeflator",
"INFL_gdpdeflator_pct_annual",
"INST_businessdisclosure",
"INST_legalrightsindex",
"KFLOW_fdicurrentusd",
"KFLOW_fdiinflows_pct_gdp",
"KFLOW_fdiinflowsusd",
"KFLOW_financiallyclosed",
"KFLOW_foreignassetsnetlcucurrent",
"KFLOW_portfolioinvequityusd",
"MONEY_m2_pct_gdp",
"MONEY_m2growth_pct_",
"MONEY_realintrate",
#
# only geo regions
#
"REGION_eapacific",
"REGION_euroarea",
"REGION_latamcarribean",
"REGION_mena",
"REGION_northamerica",
"REGION_southasia",
"REGION_subsaharan",
"REGION_lowincome",
"REGION_upperincome"
)

X.lab_credit <- c("CREDIT_bankliquidrestoass")

X.lab_gdp <- c(
"GDP_gdpgrowth2007",
"GDP_gdpgrowthlast5yrs",
"GDP_gdppercapitagrowth",
"GDP_gdppercapitapppcurrentusd",
"GDP_gdppppcurrentusd"
)

X_base <- data[X.lab] #basic dataset with min set of regressors
X_credit <- data[X.lab_credit] # add credit regressors for all non-credit-dependent-var runs
X_gdp <- data[X.lab_gdp] # add gdp vars for all non-gdp-dependent-var runs

#create datasets

#ALL
X <- as.matrix(cbind(X_base, X_credit, X_gdp))

#GDP
Xgdp <- cbind(X_base, X_credit)

#credit
Xcredit <- cbind(X_base, X_gdp)

#IBMA (BICREG)
credit <-iBMA.bicreg(Xcredit, Ycredit, thresProbne0 = .005, maxNvar = 30, nIter = 100, nbest = 5, verbose = FALSE, sorted = FALSE)
gdp <-iBMA.bicreg(Xgdp, Ygdp, thresProbne0 = .005, maxNvar = 30, nIter = 100, nbest = 5, verbose = TRUE, sorted = FALSE)

summary(credit)
summary(gdp)

# Priors 
source("c:/code/bmacompare/source_bmacompare7c.txt")
source("c:/code/bmacompare/source_summarycompare8.txt")
source("C:/code/bicreg_iterative_reverse/iterative_bmacomare/source_bmacompare_iterative_reverse2.txt")

credit_2 <- iterative.bicreg(Xcredit, Ycredit, g.prior = 2, maxVars=30, nbest=5, OR = 100000000, threshold=.005, adaptive.threshold =.002)
summary.compare(credit_2)

credit_3 <- iterative.bicreg(Xcredit, Ycredit, g.prior = 3, maxVars=30, nbest=5, OR = 100000000, threshold=.005, adaptive.threshold =.002)
summary.compare(credit_3)

credit_4 <- iterative.bicreg(Xcredit, Ycredit, g.prior = 4, maxVars=30, nbest=5, OR = 100000000, threshold=.005, adaptive.threshold =.002)
summary.compare(credit_4)

credit_5 <- iterative.bicreg(Xcredit, Ycredit, g.prior = 5, maxVars=30, nbest=5, OR = 100000000, threshold=.005, adaptive.threshold =.002)
summary.compare(credit_5)

credit_6 <- iterative.bicreg(Xcredit, Ycredit, g.prior = 6, maxVars=30, nbest=5, OR = 100000000, threshold=.005, adaptive.threshold =.002)
summary.compare(credit_6)

credit_7 <- iterative.bicreg(Xcredit, Ycredit, g.prior = 7, maxVars=30, nbest=5, OR = 100000000, threshold=.005, adaptive.threshold =.002)
summary.compare(credit_7)

credit_9 <- iterative.bicreg(Xcredit, Ycredit, g.prior = 9, maxVars=30, nbest=5, OR = 100000000, threshold=.005, adaptive.threshold =.002)
summary.compare(credit_9)

credit_12 <- iterative.bicreg(Xcredit, Ycredit, g.prior = 12, maxVars=30, nbest=5, OR = 100000000, threshold=.005, adaptive.threshold =.002)
summary.compare(credit_12)

gdp_2 <- iterative.bicreg(Xgdp, Ygdp, g.prior = 2, maxVars=30, nbest=5, OR = 100000000, threshold=.005, adaptive.threshold =.002)
summary.compare(gdp_2)

gdp_3 <- iterative.bicreg(Xgdp, Ygdp, g.prior = 3, maxVars=30, nbest=5, OR = 100000000, threshold=.005, adaptive.threshold =.002)
summary.compare(gdp_3)

gdp_4 <- iterative.bicreg(Xgdp, Ygdp, g.prior = 4, maxVars=30, nbest=5, OR = 100000000, threshold=.005, adaptive.threshold =.002)
summary.compare(gdp_4)

gdp_5 <- iterative.bicreg(Xgdp, Ygdp, g.prior = 5, maxVars=30, nbest=5, OR = 100000000, threshold=.005, adaptive.threshold =.002)
summary.compare(gdp_5)

gdp_6 <- iterative.bicreg(Xgdp, Ygdp, g.prior = 6, maxVars=30, nbest=5, OR = 100000000, threshold=.005, adaptive.threshold =.002)
summary.compare(gdp_6)

gdp_7 <- iterative.bicreg(Xgdp, Ygdp, g.prior = 7, maxVars=30, nbest=5, OR = 100000000, threshold=.005, adaptive.threshold =.002)
summary.compare(gdp_7)

gdp_9 <- iterative.bicreg(Xgdp, Ygdp, g.prior = 9, maxVars=30, nbest=5, OR = 100000000, threshold=.005, adaptive.threshold =.002)
summary.compare(gdp_9)

gdp_12 <- iterative.bicreg(Xgdp, Ygdp, g.prior = 12, maxVars=30, nbest=5, OR = 100000000, threshold=.005, adaptive.threshold =.002)
summary.compare(gdp_12)



# Priors
# (g.prior==2)-> g <- kj/n
# (g.prior==3)-> g <- (k^(1/kj))/n
# (g.prior==4)-> g <- sqrt(1/n)
# (g.prior==5)-> g <- sqrt(kj/n)
# (g.prior==6)-> g <- 1/(log(n)^3)
# (g.prior==7)-> g <- (log(kj + 1))/log(n)
# (g.prior==9)-> g <- 1/(k^2)
# (g.prior==10)->	g <- 1/max(n,k^2)
# (g.prior==12)-> g <- 1/n




